@@ -632,7 +632,7 @@ class CommandLineTest(unittest.TestCase):
         """)
     self.assertYapfReformats(unformatted_code, expected_formatted_code)
 
-  def testREtainingVerticalWhitespace(self):
+  def testRetainingVerticalWhitespace(self):
     unformatted_code = textwrap.dedent(u"""\
         def h():
             if (xxxxxxxxxxxx.yyyyyyyy(zzzzzzzzzzzzz[0]) == 'aaaaaaaaaaa' and xxxxxxxxxxxx.yyyyyyyy(zzzzzzzzzzzzz[0].mmmmmmmm[0]) == 'bbbbbbb'):
@@ -961,6 +961,40 @@ second_argument_makes_the_line_too_long):
                              extra_options=['--lines', '1-1',
                                             '--style', 'chromium'])
 
+  def testMultilineCommentFormattingDisabled(self):
+    unformatted_code = textwrap.dedent(u"""\
+        # This is a comment
+        FOO = {
+            aaaaaaaa.ZZZ: [
+                bbbbbbbbbb.Pop(),
+                # Multiline comment.
+                # Line two.
+                bbbbbbbbbb.Pop(),
+            ],
+            'xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx':
+                ('yyyyy', zzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzz),
+            '#': lambda x: x  # do nothing
+        }
+        """)
+    expected_formatted_code = textwrap.dedent(u"""\
+        # This is a comment
+        FOO = {
+            aaaaaaaa.ZZZ: [
+                bbbbbbbbbb.Pop(),
+                # Multiline comment.
+                # Line two.
+                bbbbbbbbbb.Pop(),
+            ],
+            'xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx':
+                ('yyyyy', zzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzz),
+            '#': lambda x: x  # do nothing
+        }
+        """)
+    self.assertYapfReformats(unformatted_code,
+                             expected_formatted_code,
+                             extra_options=['--lines', '1-1',
+                                            '--style', 'chromium'])
+
 
 class BadInputTest(unittest.TestCase):
   """Test yapf's behaviour when passed bad input."""
